@@ -7,8 +7,6 @@ import (
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/parameters"
 	"github.com/lmorg/murex/lang/types"
-	"github.com/lmorg/murex/utils"
-	"github.com/lmorg/murex/utils/json"
 	"github.com/mattn/go-runewidth"
 )
 
@@ -17,23 +15,28 @@ func init() {
 }
 
 const (
-	foreachJmap = "--jmap"
-	foreachStep = "--step"
+	foreachJmap     = "--jmap"
+	foreachStep     = "--step"
+	foreachParallel = "--parallel"
 )
 
 var argsForEach = &parameters.Arguments{
 	AllowAdditional: true,
 	Flags: map[string]string{
 		foreachJmap: types.Boolean,
+		"-j":        foreachJmap,
+
 		foreachStep: types.Integer,
+		"-s":        foreachStep,
+
+		foreachParallel: types.Integer,
+		"-p":            foreachParallel,
 	},
 }
 
 func cmdForEach(p *lang.Process) error {
 	flags, additional, err := p.Parameters.ParseFlags(argsForEach)
-	//flags := map[string]string{}
-	//additional := p.Parameters.StringArray()
-	//var err error
+
 	if err != nil {
 		p.Stdout.SetDataType(types.Null)
 		return err
@@ -43,12 +46,15 @@ func cmdForEach(p *lang.Process) error {
 	case flags[foreachJmap] == types.TrueString:
 		return cmdForEachJmap(p)
 
+	case flags[foreachParallel] != "":
+		return cmdForEachParallel(p, flags, additional)
+
 	default:
 		return cmdForEachDefault(p, flags, additional)
 	}
 }
 
-func convertToByte(v interface{}) ([]byte, error) {
+func convertToByte(v any) ([]byte, error) {
 	s, err := types.ConvertGoType(v, types.String)
 	if err != nil {
 		return nil, err
@@ -57,16 +63,16 @@ func convertToByte(v interface{}) ([]byte, error) {
 	return []byte(s.(string)), nil
 }
 
-func getSteps(flags map[string]string) (int, []interface{}, error) {
-	steps, err := types.ConvertGoType(flags[foreachStep], types.Integer)
+func getFlagValueInt(flags map[string]string, flagName string) (int, error) {
+	v, err := types.ConvertGoType(flags[flagName], types.Integer)
 	if err != nil {
-		return 0, nil, fmt.Errorf(`expecting integer for %s, instead got "%s": %s`, foreachStep, flags[foreachStep], err.Error())
+		return 0, fmt.Errorf(`expecting integer for %s, instead got "%s": %s`, flagName, flags[flagName], err.Error())
 	}
 
-	return steps.(int), make([]any, steps.(int)), nil
+	return v.(int), nil
 }
 
-func cmdForEachDefault(p *lang.Process, flags map[string]string, additional []string) error {
+func forEachInitializer(p *lang.Process, additional []string) (block []rune, varName string, err error) {
 	dataType := p.Stdin.GetDataType()
 	if dataType == types.Json {
 		p.Stdout.SetDataType(types.JsonLines)
@@ -74,11 +80,6 @@ func cmdForEachDefault(p *lang.Process, flags map[string]string, additional []st
 		p.Stdout.SetDataType(dataType)
 	}
 
-	var (
-		block   []rune
-		varName string
-	)
-
 	switch len(additional) {
 	case 1:
 		varName = "!"
@@ -89,13 +90,22 @@ func cmdForEachDefault(p *lang.Process, flags map[string]string, additional []st
 		block = []rune(additional[1])
 
 	default:
-		return errors.New("invalid number of parameters")
+		return nil, "", errors.New("invalid number of parameters")
 	}
 	if !types.IsBlockRune(block) {
-		return fmt.Errorf("invalid code block: `%s`", runewidth.Truncate(string(block), 70, "…"))
+		return nil, "", fmt.Errorf("invalid code block: `%s`", runewidth.Truncate(string(block), 70, "…"))
 	}
 
-	steps, slice, err := getSteps(flags)
+	return
+}
+
+func cmdForEachDefault(p *lang.Process, flags map[string]string, additional []string) error {
+	block, varName, err := forEachInitializer(p, additional)
+	if err != nil {
+		return err
+	}
+
+	steps, err := getFlagValueInt(flags, foreachStep)
 	if err != nil {
 		return err
 	}
@@ -103,9 +113,10 @@ func cmdForEachDefault(p *lang.Process, flags map[string]string, additional []st
 	var (
 		step      int
 		iteration int
+		slice     = make([]any, steps)
 	)
 
-	err = p.Stdin.ReadArrayWithType(p.Context, func(varValue interface{}, dataType string) {
+	err = p.Stdin.ReadArrayWithType(p.Context, func(varValue any, dataType string) {
 		if steps > 0 {
 			varValue, _ = marshal(p, varValue, dataType)
 			slice[step] = varValue
@@ -161,7 +172,7 @@ func setMetaValues(p *lang.Process, iteration int) bool {
 	return true
 }
 
-func forEachInnerLoop(p *lang.Process, block []rune, varName string, varValue interface{}, dataType string, iteration int) {
+func forEachInnerLoop(p *lang.Process, block []rune, varName string, varValue any, dataType string, iteration int) {
 	var b []byte
 	b, err := convertToByte(varValue)
 	if err != nil {
@@ -201,79 +212,3 @@ func forEachInnerLoop(p *lang.Process, block []rune, varName string, varValue in
 		return
 	}
 }
-
-func cmdForEachJmap(p *lang.Process) error {
-	p.Stdout.SetDataType(types.Json)
-
-	varName, err := p.Parameters.String(1)
-	if err != nil {
-		return err
-	}
-
-	blockKey, err := p.Parameters.Block(2)
-	if err != nil {
-		return err
-	}
-
-	blockVal, err := p.Parameters.Block(3)
-	if err != nil {
-		return err
-	}
-
-	var (
-		m         = make(map[string]string)
-		iteration int
-	)
-
-	err = p.Stdin.ReadArrayWithType(p.Context, func(v interface{}, dt string) {
-		var b []byte
-		b, err = convertToByte(v)
-		if err != nil {
-			p.Done()
-			return
-		}
-
-		if len(b) == 0 || p.HasCancelled() {
-			return
-		}
-
-		if varName != "!" {
-			p.Variables.Set(p, varName, v, dt)
-		}
-
-		iteration++
-		if !setMetaValues(p, iteration) {
-			return
-		}
-
-		forkKey := p.Fork(lang.F_PARENT_VARTABLE | lang.F_NO_STDIN | lang.F_CREATE_STDOUT)
-		forkKey.Execute(blockKey)
-		bKey, err := forkKey.Stdout.ReadAll()
-		if err != nil {
-			p.Stderr.Writeln([]byte(err.Error()))
-			p.Kill()
-		}
-
-		forkVal := p.Fork(lang.F_PARENT_VARTABLE | lang.F_NO_STDIN | lang.F_CREATE_STDOUT)
-		forkVal.Execute(blockVal)
-		bVal, err := forkVal.Stdout.ReadAll()
-		if err != nil {
-			p.Stderr.Writeln([]byte(err.Error()))
-			p.Kill()
-		}
-
-		m[string(utils.CrLfTrim(bKey))] = string(utils.CrLfTrim(bVal))
-	})
-
-	if err != nil {
-		return err
-	}
-
-	b, err := json.Marshal(m, p.Stdout.IsTTY())
-	if err != nil {
-		return err
-	}
-
-	_, err = p.Stdout.Write(b)
-	return err
-}
