@@ -11,7 +11,6 @@ import (
 
 func init() {
 	lang.DefineMethod("exec", lang.External, types.Any, types.Generic)
-	lang.DefineFunction("die", cmdDie, types.Null)
 	lang.DefineFunction("exit", cmdExit, types.Null)
 	lang.DefineFunction("null", cmdNull, types.Null)
 	lang.DefineFunction("true", cmdTrue, types.Boolean)
@@ -66,15 +65,6 @@ func cmdNot(p *lang.Process) error {
 	return nil
 }
 
-func cmdDie(p *lang.Process) error {
-	p.Stdout.SetDataType(types.Die)
-
-	lang.FeatureDeprecatedBuiltin(p)
-
-	lang.Exit(1)
-	return nil
-}
-
 func cmdExit(p *lang.Process) error {
 	p.Stdout.SetDataType(types.Null)
 
