@@ -7,4 +7,4 @@ package optional
 // but it's a handy pipe to have if you wish to send emails from the command
 // line using idiomatic murex syntax and controls
 
-import _ "github.com/lmorg/murex/builtins/pipes/mail" // piping data via esmail
+import _ "github.com/lmorg/murex/builtins/pipes/mail" // piping data via email
