@@ -4,10 +4,11 @@
 package term
 
 import (
+	"os"
 	"sync"
 	"syscall/js"
 
-	"github.com/lmorg/murex/utils/readline"
+	"github.com/lmorg/readline/v4"
 )
 
 var divMutex sync.Mutex
@@ -25,3 +26,7 @@ func vtermWrite(r []rune) {
 
 	divMutex.Unlock()
 }
+
+func (t *term) File() *os.File {
+	return nil
+}
