@@ -28,7 +28,7 @@ func readArray(ctx context.Context, read stdio.Io, callback func([]byte)) error
 	return nil
 }
 
-func readArrayWithType(ctx context.Context, read stdio.Io, callback func(interface{}, string)) error {
+func readArrayWithType(ctx context.Context, read stdio.Io, callback func(any, string)) error {
 	scanner := bufio.NewScanner(read)
 	for scanner.Scan() {
 		select {
