@@ -10,7 +10,7 @@ import (
 	"github.com/lmorg/murex/lang/types"
 )
 
-func readArrayWithType(ctx context.Context, read stdio.Io, callback func(interface{}, string)) error {
+func readArrayWithType(ctx context.Context, read stdio.Io, callback func(any, string)) error {
 	scanner := bufio.NewScanner(read)
 	for scanner.Scan() {
 		select {
