@@ -13,6 +13,7 @@ const typeName = "toml"
 var errNakedArrays = errors.New("the TOML specification doesn't support naked arrays")
 
 func init() {
+	lang.RegisterDataType(typeName, lang.DataTypeIsKeyValue)
 	stdio.RegisterReadArray(typeName, readArray)
 	stdio.RegisterReadArrayWithType(typeName, readArrayWithType)
 	stdio.RegisterReadMap(typeName, readMap)
@@ -37,7 +38,7 @@ func init() {
 }
 
 func readIndex(p *lang.Process, params []string) error {
-	var jInterface interface{}
+	var jInterface any
 
 	b, err := p.Stdin.ReadAll()
 	if err != nil {
@@ -52,11 +53,11 @@ func readIndex(p *lang.Process, params []string) error {
 	return lang.IndexTemplateObject(p, params, &jInterface, toml.Marshal)
 }
 
-func marshal(_ *lang.Process, v interface{}) ([]byte, error) {
+func marshal(_ *lang.Process, v any) ([]byte, error) {
 	return toml.Marshal(v)
 }
 
-func unmarshal(p *lang.Process) (v interface{}, err error) {
+func unmarshal(p *lang.Process) (v any, err error) {
 	b, err := p.Stdin.ReadAll()
 	if err != nil {
 		return
