@@ -1,7 +1,6 @@
 package defaults_test
 
 import (
-	"strings"
 	"testing"
 
 	"github.com/lmorg/murex/config"
@@ -12,11 +11,9 @@ import (
 func TestDefaultProfileNotEmpty(t *testing.T) {
 	count.Tests(t, 1)
 
-	s := string(defaults.DefaultMurexProfile())
-	if strings.TrimSpace(s) == "" {
+	if len(defaults.DefaultProfiles) == 0 {
 		t.Error("Empty default profile")
 	}
-
 }
 
 func TestDefaultConfigLoads(t *testing.T) {
