@@ -10,6 +10,7 @@ import (
 
 	"github.com/lmorg/murex/app"
 	"github.com/lmorg/murex/builtins/pipes/term"
+	profilepaths "github.com/lmorg/murex/config/profile/paths"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/ref"
 	"github.com/lmorg/murex/lang/types"
@@ -34,6 +35,8 @@ type Module struct {
 	Summary      string
 	Version      string
 	Source       string
+	Preload      string
+	pkg          *Package
 	Package      string
 	Disabled     bool
 	Loaded       bool
@@ -47,6 +50,7 @@ type Dependencies struct {
 	Required     []string
 	Platform     []string
 	MurexVersion string
+	ChangeLog    map[string]string
 }
 
 // Package is some basic details about the package itself as seen in the
@@ -76,10 +80,15 @@ func isDisabled(name string) bool {
 
 // Path returns the full path to the murex script that is sourced into your running shell
 func (m *Module) Path() string {
-	return ModulePath() + m.Package + consts.PathSlash + m.Source
+	return profilepaths.ModulePath() + m.Package + consts.PathSlash + m.Source
 }
 
-func (m *Module) validate() error {
+// Path returns the full path to the murex script that is sourced into your running shell
+func (m *Module) PreloadPath() string {
+	return profilepaths.ModulePath() + m.Package + consts.PathSlash + m.Preload
+}
+
+func (m *Module) validate(preload bool) error {
 	var message string
 	if strings.TrimSpace(m.Name) == "" {
 		message += `  * Property "Name" is empty. This should contain the name of the module` + utils.NewLineString
@@ -107,15 +116,28 @@ func (m *Module) validate() error {
 		}
 	}
 
+	if m.Dependencies.MurexVersion == "" {
+		m.Dependencies.MurexVersion = m.pkg.Dependencies.MurexVersion
+	}
+
 	if message != "" {
 		return errors.New(message)
 	}
 
+	if preload {
+		return nil
+	}
+
 	return m.checkDependencies()
 }
 
-func (m *Module) execute() error {
-	file, err := os.OpenFile(m.Path(), os.O_RDONLY, 0640)
+var msgLoad = map[bool]string{
+	true:  "Configuring",
+	false: "Loading",
+}
+
+func (m *Module) execute(path string, preload bool) error {
+	file, err := os.OpenFile(path, os.O_RDONLY, 0640)
 	if err != nil {
 		return err
 	}
@@ -131,7 +153,7 @@ func (m *Module) execute() error {
 
 	quiet, _ := lang.ShellProcess.Config.Get("shell", "quiet", types.Boolean)
 	if v, ok := quiet.(bool); !ok || !v {
-		os.Stderr.WriteString(fmt.Sprintf("Loading module `%s/%s`%s", m.Package, m.Name, utils.NewLineString))
+		os.Stderr.WriteString(fmt.Sprintf("%s module `%s/%s`%s", msgLoad[preload], m.Package, m.Name, utils.NewLineString))
 	}
 
 	fork := lang.ShellProcess.Fork(lang.F_NEW_MODULE | lang.F_FUNCTION | lang.F_NO_STDIN)
@@ -174,13 +196,11 @@ checkDeps:
 	var message string
 
 	// check supported version
-	if m.Dependencies.MurexVersion != "" {
-		ok, err := semver.Compare(app.Version(), m.Dependencies.MurexVersion)
-		if err != nil {
-			message += "  * Error checking supported Murex version: " + err.Error()
-		} else if !ok {
-			message += "  * This module is not supported for this version of Murex"
-		}
+	ok, err := semver.Compare(app.Semver().String(), m.Dependencies.MurexVersion)
+	if err != nil {
+		message += "  * Error checking supported Murex version: " + err.Error()
+	} else if !ok {
+		message += "  * This module is not supported for this version of Murex"
 	}
 
 	// check dependencies
