@@ -8,6 +8,8 @@ import (
 	"strings"
 
 	"github.com/lmorg/murex/app"
+	profilepaths "github.com/lmorg/murex/config/profile/paths"
+	"github.com/lmorg/murex/lang/modver"
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/consts"
 	"github.com/lmorg/murex/utils/semver"
@@ -26,7 +28,7 @@ const (
 	IgnoredExt = ".ignore"
 )
 
-func modules(modulePath string) error {
+func modules(modulePath string, preload bool) error {
 	// Check module path
 	fi, err := os.Stat(modulePath)
 	if os.IsNotExist(err) {
@@ -57,7 +59,7 @@ func modules(modulePath string) error {
 	var message string
 
 	for i := range paths {
-		_, err = LoadPackage(paths[i], true)
+		_, err = LoadPackage(paths[i], true, preload)
 		if err != nil {
 			message += err.Error() + utils.NewLineString
 		}
@@ -76,7 +78,7 @@ func disabledFile() error {
 		return err
 	}
 
-	return ReadJson(ModulePath()+DisabledFile, &disabled)
+	return ReadJson(profilepaths.ModulePath()+DisabledFile, &disabled)
 }
 
 func packageFile() error {
@@ -84,7 +86,7 @@ func packageFile() error {
 }
 
 func autoFile(name string) error {
-	filename := ModulePath() + name
+	filename := profilepaths.ModulePath() + name
 
 	fi, err := os.Stat(filename)
 	switch {
@@ -110,7 +112,7 @@ func autoFile(name string) error {
 
 // LoadPackage reads in the contents of the package and then validates and
 // sources each module within. The path value should be an absolute path.
-func LoadPackage(path string, execute bool) ([]Module, error) {
+func LoadPackage(path string, execute bool, preload bool) ([]Module, error) {
 	// Because we are expecting an absolute path and any errors with it being
 	// relative will have been compiled into the Go code, we want to raise a
 	// panic here so those errors get caught during testing rather than buggy
@@ -130,7 +132,7 @@ func LoadPackage(path string, execute bool) ([]Module, error) {
 	}
 
 	// ignore hidden directories. eg version control (.git), IDE workspace
-	// settings, OS X metadirectories and other guff.
+	// settings, macOS meta-directories and other guff.
 	if strings.HasPrefix(f.Name(), ".") {
 		return nil, nil
 	}
@@ -150,13 +152,14 @@ func LoadPackage(path string, execute bool) ([]Module, error) {
 		return nil, err
 	}
 
-	if pkg.Dependencies.MurexVersion != "" {
-		ok, err := semver.Compare(app.Version(), pkg.Dependencies.MurexVersion)
-		if err != nil {
-			message += fmt.Sprintf("* Package '%s': Error checking supported Murex version: %s\n", pkg.Name, err.Error())
-		} else if !ok {
-			message += fmt.Sprintf("* Package '%s': Package not supported (%s) for this version of Murex (%s)\n", pkg.Name, pkg.Dependencies.MurexVersion, app.Version())
-		}
+	if pkg.Dependencies.MurexVersion == "" {
+		pkg.Dependencies.MurexVersion = fmt.Sprintf(">= %s", modver.ModuleDefault)
+	}
+	ok, err := semver.Compare(app.Semver().String(), pkg.Dependencies.MurexVersion)
+	if err != nil {
+		message += fmt.Sprintf("* Package '%s': Error checking supported Murex version: %s\n", pkg.Name, err.Error())
+	} else if !ok {
+		message += fmt.Sprintf("* Package '%s': Package not supported (%s) for this version of Murex (%s)\n", pkg.Name, pkg.Dependencies.MurexVersion, app.Version())
 	}
 
 	// load modules
@@ -173,15 +176,27 @@ func LoadPackage(path string, execute bool) ([]Module, error) {
 	}
 
 	for i := range module {
+		module[i].pkg = &pkg
 		module[i].Package = f.Name()
 		module[i].Disabled = module[i].Disabled || isDisabled(module[i].Package+"/"+module[i].Name)
-		err = module[i].validate()
+
+		var srcPath string
+		if preload {
+			if module[i].Preload == "" {
+				continue
+			}
+			srcPath = module[i].PreloadPath()
+		} else {
+			srcPath = module[i].Path()
+		}
+
+		err = module[i].validate(preload)
 		if err != nil && !module[i].Disabled {
 			message += fmt.Sprintf(
 				"* Package '%s': Error loading module `%s` in path `%s`:%s%s%s",
 				pkg.Name,
 				module[i].Name,
-				module[i].Path(),
+				srcPath,
 				utils.NewLineString,
 				err.Error(),
 				utils.NewLineString,
@@ -193,6 +208,20 @@ func LoadPackage(path string, execute bool) ([]Module, error) {
 			continue
 		}
 
+		useMurexVersion, err := semver.VersionFromComparison(module[i].Dependencies.MurexVersion)
+		if err != nil {
+			message += fmt.Sprintf(
+				"* Package '%s': Error reading Murex version string in module `%s` in path `%s`:%s%s%s",
+				pkg.Name,
+				module[i].Name,
+				srcPath,
+				utils.NewLineString,
+				err.Error(),
+				utils.NewLineString,
+			)
+		}
+		modver.Set(fmt.Sprintf("%s/%s", pkg.Name, module[i].Name), useMurexVersion)
+
 		err = os.Chdir(path)
 		if err != nil {
 			os.Stderr.WriteString(err.Error())
@@ -200,13 +229,13 @@ func LoadPackage(path string, execute bool) ([]Module, error) {
 
 		module[i].Loaded = true
 
-		err = module[i].execute()
+		err = module[i].execute(srcPath, preload)
 		if err != nil {
 			message += fmt.Sprintf(
 				"* Package '%s': Error sourcing module `%s` in path `%s`:%s%s%s",
 				pkg.Name,
 				module[i].Name,
-				module[i].Path(),
+				srcPath,
 				utils.NewLineString,
 				err.Error(),
 				utils.NewLineString,
@@ -214,13 +243,13 @@ func LoadPackage(path string, execute bool) ([]Module, error) {
 		}
 	}
 
-	if execute {
+	if execute && !preload {
 		Packages[f.Name()] = module
+	}
 
-		err = os.Chdir(pwd)
-		if err != nil {
-			message += err.Error() + utils.NewLineString
-		}
+	err = os.Chdir(pwd)
+	if err != nil {
+		message += err.Error() + utils.NewLineString
 	}
 
 	if message != "" {
