@@ -6,9 +6,12 @@ import (
 	"strings"
 )
 
-func ElementLookup(v interface{}, path string) (interface{}, error) {
-	var err error
+const (
+	ELEMENT_META_ROOT    = "__MUREX_ELEMENT_META_ROOT_KEY__"
+	ELEMENT_META_ELEMENT = "__MUREX_ELEMENT_META_ELEMENT_KEY__"
+)
 
+func ElementLookup(v any, path string, dataType string) (any, error) {
 	if len(path) < 2 {
 		return nil, fmt.Errorf("invalid path for element lookup: `%s` is too short", path)
 	}
@@ -19,8 +22,19 @@ func ElementLookup(v interface{}, path string) (interface{}, error) {
 		break
 	}
 
+	if dataType == "xml" {
+		m, ok := v.(map[string]any)
+		if ok && len(m) == 1 {
+			for root := range m {
+				path = separator + root + path
+			}
+		}
+	}
+
 	pathSplit := strings.Split(path, separator)
+
 	obj := v
+	var err error
 
 	for i := 1; i < len(pathSplit); i++ {
 		if len(pathSplit[i]) == 0 {
@@ -37,10 +51,46 @@ func ElementLookup(v interface{}, path string) (interface{}, error) {
 		}
 	}
 
+	if dataType == "xml" {
+		l := len(pathSplit)
+		switch t := obj.(type) {
+		case map[string]any:
+			t[ELEMENT_META_ROOT] = pathSplit[l-1]
+			return t, nil
+
+		case []string:
+			var rootKey string
+			if len(pathSplit) > 1 {
+				rootKey = pathSplit[l-2]
+			} else {
+				rootKey = "xml"
+			}
+			t = append([]string{
+				ELEMENT_META_ROOT + rootKey,
+				ELEMENT_META_ELEMENT + pathSplit[l-1]},
+				t...)
+			return t, nil
+
+		case []any:
+			var rootKey string
+			if len(pathSplit) > 1 {
+				rootKey = pathSplit[l-2]
+			} else {
+				rootKey = "xml"
+			}
+			t = append([]any{
+				ELEMENT_META_ROOT + rootKey,
+				ELEMENT_META_ELEMENT + pathSplit[l-1]},
+				t...)
+			return t, nil
+
+		}
+	}
+
 	return obj, nil
 }
 
-func elementRecursiveLookup(path []string, i int, obj interface{}) (interface{}, error) {
+func elementRecursiveLookup(path []string, i int, obj any) (any, error) {
 	switch v := obj.(type) {
 	case []string:
 		i, err := isValidElementIndex(path[i], len(v))
@@ -49,14 +99,14 @@ func elementRecursiveLookup(path []string, i int, obj interface{}) (interface{},
 		}
 		return v[i], nil
 
-	case []interface{}:
+	case []any:
 		i, err := isValidElementIndex(path[i], len(v))
 		if err != nil {
 			return nil, err
 		}
 		return v[i], nil
 
-	case []map[string]interface{}:
+	case []map[string]any:
 		i, err := isValidElementIndex(path[i], len(v))
 		if err != nil {
 			return nil, err
@@ -79,7 +129,7 @@ func elementRecursiveLookup(path []string, i int, obj interface{}) (interface{},
 			return "", nil
 		}
 
-	case map[string]interface{}:
+	case map[string]any:
 		switch {
 		case v[path[i]] != nil:
 			return v[path[i]], nil
@@ -95,7 +145,7 @@ func elementRecursiveLookup(path []string, i int, obj interface{}) (interface{},
 			return nil, fmt.Errorf("key '%s' not found", path[i])
 		}
 
-	case map[interface{}]interface{}:
+	case map[any]any:
 		switch {
 		case v[path[i]] != nil:
 			return v[path[i]], nil
