@@ -6,7 +6,9 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/lmorg/murex/lang/modver"
 	"github.com/lmorg/murex/lang/types"
+	"github.com/lmorg/murex/utils/semver"
 )
 
 type indexValueT interface {
@@ -19,6 +21,7 @@ func IndexTemplateObject(p *Process, params []string, object *any, marshaller fu
 	if p.IsNot {
 		return itoNot(p, params, object, marshaller)
 	}
+
 	return itoIndex(p, params, object, marshaller)
 }
 
@@ -99,16 +102,18 @@ func itoIndexArray[V indexValueT](p *Process, params []string, v []V, marshaller
 func itoIndexMap[K comparable, V indexValueT](p *Process, params []string, v map[K]V, marshaller func(any) ([]byte, error)) error {
 	var (
 		objArray []any
+		objMap   = make(map[string]any)
 		obj      any
 		err      error
 	)
 
 	for i := range params {
 		if len(params[i]) > 2 && params[i][0] == '[' && params[i][len(params[i])-1] == ']' {
-			obj, err = ElementLookup(v, params[i][1:len(params[i])-1])
+			obj, err = ElementLookup(v, params[i][1:len(params[i])-1], "")
 			if err != nil {
 				return err
 			}
+			params[i] = params[i][2 : len(params[i])-1]
 
 		} else {
 			var (
@@ -140,7 +145,11 @@ func itoIndexMap[K comparable, V indexValueT](p *Process, params []string, v map
 		}
 
 		if len(params) > 1 {
-			objArray = append(objArray, obj)
+			if modver.Get(p.FileRef.Source.Module).Compare(semver.Version8_0).IsLessThan() {
+				objArray = append(objArray, obj)
+			} else {
+				objMap[params[i]] = obj
+			}
 
 		} else {
 			switch obj := obj.(type) {
@@ -173,15 +182,25 @@ func itoIndexMap[K comparable, V indexValueT](p *Process, params []string, v map
 			}
 		}
 	}
-	if len(objArray) > 0 {
-		b, err := marshaller(objArray)
-		if err != nil {
-			return err
-		}
-		p.Stdout.Writeln(b)
-	}
-	return nil
 
+	if modver.Get(p.FileRef.Source.Module).Compare(semver.Version8_0).IsLessThan() {
+		if len(objArray) == 0 {
+			return nil
+		}
+		obj = objArray
+	} else {
+		if len(objMap) == 0 {
+			return nil
+		}
+		obj = objMap
+	}
+
+	b, err := marshaller(obj)
+	if err != nil {
+		return err
+	}
+	_, err = p.Stdout.Writeln(b)
+	return err
 }
 
 // itoNot requires the indexes to be explicit
