@@ -2,14 +2,14 @@ package expressions
 
 import "fmt"
 
-func (tree *ParserT) Dump() interface{} {
+func (tree *ParserT) Dump() any {
 	var (
-		dump  = make(map[string]interface{})
-		nodes = make([]interface{}, len(tree.ast))
+		dump  = make(map[string]any)
+		nodes = make([]any, len(tree.ast))
 	)
 
 	for i := range tree.ast {
-		node := make(map[string]interface{})
+		node := make(map[string]any)
 		node["key"] = tree.ast[i].key.String()
 		node["value"] = tree.ast[i].Value()
 		node["pos"] = tree.ast[i].pos
@@ -34,7 +34,7 @@ func (tree *ParserT) Dump() interface{} {
 	dump["charOffset"] = tree.charOffset
 	dump["astPos"] = tree.astPos
 	dump["expression"] = string(tree.expression)
-	dump["statement"] = map[string]interface{}{
+	dump["statement"] = map[string]any{
 		"command":    tree.statement.String(),
 		"parameters": tree.statement.Parameters(),
 	}
