@@ -63,18 +63,18 @@ func execSubShellScalar(tree *ParserT, block []rune, strOrVal varFormatting) (*p
 	}
 	b, err := fork.Stdout.ReadAll()
 	if err != nil {
-		return val, fmt.Errorf("cannot read from subshell's STDOUT: %s", err.Error())
+		return val, fmt.Errorf("cannot read from sub-shell's stdout: %s", err.Error())
 	}
 
 	b = utils.CrLfTrim(b)
 	val.DataType = fork.Stdout.GetDataType()
 
-	val.Value, err = formatBytes(b, val.DataType, strOrVal)
+	val.Value, err = formatBytes(tree, b, val.DataType, strOrVal)
 	return val, err
 }
 
 func execSubShellArray(tree *ParserT, block []rune, strOrVal varFormatting) (*primitives.Value, error) {
-	var slice []interface{}
+	var slice []any
 	val := new(primitives.Value)
 	var err error
 
@@ -93,7 +93,7 @@ func execSubShellArray(tree *ParserT, block []rune, strOrVal varFormatting) (*pr
 			slice = append(slice, string(b))
 		})
 	case varAsValue:
-		err = fork.Stdout.ReadArrayWithType(tree.p.Context, func(v interface{}, _ string) {
+		err = fork.Stdout.ReadArrayWithType(tree.p.Context, func(v any, _ string) {
 			slice = append(slice, v)
 		})
 	default:
