@@ -60,21 +60,42 @@ func (tree *ParserT) validateExpression() error {
 			node.dt = primitive
 
 		} else {
-			if node.key < symbols.Operations {
-				return raiseError(tree.expression, node, 0, "expecting an operation")
-			}
 
-			switch node.key {
-			case symbols.Add, symbols.GreaterThan, symbols.LessThan:
-				if prev == nil || prev.key == symbols.Bareword ||
-					next == nil || next.key == symbols.Bareword {
-					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s barewords", node.key))
+			switch {
+			case prev == nil:
+				return raiseError(tree.expression, node, 0, fmt.Sprintf("nil symbol preceding %s", node.key))
+
+			case node.key == symbols.PlusPlus, node.key == symbols.MinusMinus:
+				if prev.key != symbols.Scalar {
+					return raiseError(tree.expression, node, 0, fmt.Sprintf("%s can only follow a %s, instead got %s", node.key, symbols.Scalar, prev.key))
+				}
+				expectValue = !expectValue
+
+			case next == nil:
+				return raiseError(tree.expression, node, 0, fmt.Sprintf("nil symbol following %s", node.key))
+
+			case node.key < symbols.Operations:
+				return raiseError(tree.expression, node, 0, fmt.Sprintf("expecting an operation, instead got %s", node.key))
+
+			case node.key >= symbols.Add:
+				if !isSymbolNumeric(prev.key) {
+					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s non-numeric data types, left is %s", node.key, prev.key))
+				}
+				if !isSymbolNumeric(next.key) {
+					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s non-numeric data types, right is %s", node.key, next.key))
 				}
 
-			case symbols.Subtract, symbols.Divide, symbols.Multiply:
-				if prev == nil || (prev.key != symbols.Number && prev.key != symbols.Calculated && prev.key != symbols.SubExpressionBegin && prev.key != symbols.Scalar) ||
-					next == nil || (next.key != symbols.Number && next.key != symbols.Calculated && next.key != symbols.SubExpressionBegin && next.key != symbols.Scalar) {
-					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s non-numeric data types", node.key))
+			case node.key >= symbols.Elvis:
+				if prev.key == symbols.Bareword {
+					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s left %s", node.key, prev.key))
+				}
+				if next.key == symbols.Bareword {
+					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s right %s", node.key, next.key))
+				}
+
+			default:
+				if !isSymbolAssignable(prev.key) {
+					return raiseError(tree.expression, node, 0, fmt.Sprintf("cannot %s to %s", node.key, prev.key))
 				}
 			}
 		}
@@ -87,3 +108,16 @@ func (tree *ParserT) validateExpression() error {
 
 	return nil
 }
+
+func isSymbolNumeric(sym symbols.Exp) bool {
+	return sym == symbols.Number ||
+		sym == symbols.Calculated ||
+		sym == symbols.SubExpressionBegin ||
+		sym == symbols.Scalar
+}
+
+func isSymbolAssignable(sym symbols.Exp) bool {
+	return sym == symbols.Bareword ||
+		sym == symbols.Scalar ||
+		sym == symbols.SubExpressionBegin
+}
