@@ -39,7 +39,8 @@ type Process struct {
 	HasStopped         chan bool `json:"-"`
 	Done               func()    `json:"-"`
 	Kill               func()    `json:"-"`
-	Exec               process.Exec
+	SystemProcess      *process.SystemProcess
+	Envs               []string
 	Scope              *Process `json:"-"`
 	Parent             *Process `json:"-"`
 	Previous           *Process `json:"-"`
@@ -54,7 +55,8 @@ type Process struct {
 	hasTerminatedM     sync.Mutex `json:"-"`
 	hasTerminatedV     bool
 	State              state.State
-	Background         process.Background
+	Background         process.AtomicBool
+	HasJobId           process.AtomicBool
 	RunMode            runmode.RunMode
 	Config             *config.Config
 	Tests              *Tests
@@ -72,22 +74,22 @@ type Process struct {
 
 func (p *Process) Dump() map[string]any {
 	return map[string]any{
-		"Id":           p.Id,
-		"Cache":        p.cache != nil && p.cache.use,
-		"Raw":          string(p.raw),
-		"Name":         p.Name.String(),
-		"Parameters":   p.Parameters.Dump(),
-		"NamedPipes":   p.namedPipes,
-		"Stdin":        statsToStruct(p.Stdin),
-		"Stdout":       statsToStruct(p.Stdout),
-		"Stderr":       statsToStruct(p.Stderr),
-		"stdoutOldPtr": statsToStruct(p.stdoutOldPtr),
-		"ExitNum":      p.ExitNum,
-		"Forks":        p.Forks.GetForks(),
-		"IsFork":       p.IsFork,
-		//"Done":             p.Done,
-		//"Kill":             p.Kill,
-		"ExecPid":          p.Exec.Pid(),
+		"Id":               p.Id,
+		"Cache":            p.cache != nil && p.cache.use,
+		"Raw":              string(p.raw),
+		"Name":             p.Name.String(),
+		"Parameters":       p.Parameters.Dump(),
+		"NamedPipes":       p.namedPipes,
+		"Stdin":            statsToStruct(p.Stdin),
+		"Stdout":           statsToStruct(p.Stdout),
+		"Stderr":           statsToStruct(p.Stderr),
+		"stdoutOldPtr":     statsToStruct(p.stdoutOldPtr),
+		"ExitNum":          p.ExitNum,
+		"Forks":            p.Forks.GetForks(),
+		"IsFork":           p.IsFork,
+		"Done":             p.cache != nil,
+		"Kill":             p.cache != nil,
+		"SysProcId":        _jsonfySysProc(p),
 		"ScopeFid":         p.Scope.Id,
 		"ParentFid":        p.Parent.Id,
 		"PreviousFid":      p.Previous.Id,
@@ -104,6 +106,7 @@ func (p *Process) Dump() map[string]any {
 		//"HasStopped":       p.hasCancelledStopped(),
 		"State":         p.State.String(),
 		"Background":    p.Background.Get(),
+		"HasJobId":      p.HasJobId.Get(),
 		"RunMode":       p.RunMode.String(),
 		"RunModeStrict": p.RunMode.IsStrict(),
 		//Config             *config.Config
@@ -121,6 +124,18 @@ func (p *Process) Dump() map[string]any {
 	}
 }
 
+func (p *Process) GetRaw() string {
+	return string(p.raw)
+}
+
+func _jsonfySysProc(p *Process) any {
+	if !p.SystemProcess.External() {
+		return nil
+	}
+
+	return p.SystemProcess.Pid()
+}
+
 type statsT struct {
 	Read    uint64
 	Written uint64
@@ -229,9 +244,6 @@ func newForegroundProc() *foregroundProc {
 func (fp *foregroundProc) Get() *Process {
 	fp.mutex.Lock()
 	p := fp.p
-	//if p == nil {
-	//	panic("Get() retrieved p")
-	//}
 	fp.mutex.Unlock()
 
 	return p
@@ -243,7 +255,5 @@ func (fp *foregroundProc) Set(p *Process) {
 		panic("nil p in (fp *foregroundProc) Set(p *Process)")
 	}
 	fp.p = p
-	//debug.Json("fp.Set", p)
-	//debug.Json("fp.p", fp.p)
 	fp.mutex.Unlock()
 }
