@@ -33,11 +33,11 @@ func parseRedirection(p *Process) {
 			}
 
 		case len(name) > 4 && name[:4] == "env:":
-			p.Exec.Env = append(p.Exec.Env, name[4:])
+			p.Envs = append(p.Envs, name[4:])
 
 		case len(name) > 4 && name[:4] == "fid:":
 			varName := name[4:]
-			err := p.Variables.Set(p, varName, p.Id, types.Integer)
+			err := p.Variables.Set(p, varName, int(p.Id), types.Integer)
 			if err != nil {
 				ShellProcess.Stderr.Writeln([]byte(
 					fmt.Sprintf("Cannot write variable '%s': %s", varName, err.Error()),
@@ -46,14 +46,14 @@ func parseRedirection(p *Process) {
 
 		case len(name) > 4 && name[:4] == "pid:":
 			varName := name[4:]
-			p.Exec.Callback = func(pid int) {
-				err := p.Variables.Set(p, varName, pid, types.Integer)
+			go func() {
+				err := p.Variables.Set(p, varName, p.SystemProcess.WaitForPid(), types.Integer)
 				if err != nil {
 					ShellProcess.Stderr.Writeln([]byte(
 						fmt.Sprintf("Cannot write variable '%s': %s", varName, err.Error()),
 					))
 				}
-			}
+			}()
 
 		case name[0] == '!':
 			if p.NamedPipeErr == "" {
