@@ -16,13 +16,15 @@ var (
 	Summary = New()
 )
 
+const _CACHE_TTL_DAYS = 30
+
 func Get(cmd string, checkManPage bool) (r []rune) {
 	var summary string
 	if cache.Read(cache.HINT_SUMMARY, cmd, &summary) {
-		return r
+		return []rune(summary)
 	}
 
-	defer func() { cache.Write(cache.HINT_SUMMARY, cmd, string(r), cache.Days(30)) }()
+	defer func() { cache.Write(cache.HINT_SUMMARY, cmd, string(r), cache.Days(_CACHE_TTL_DAYS)) }()
 
 	custom := Summary.Get(cmd)
 	if custom != "" {
