@@ -4,6 +4,7 @@ import (
 	"embed"
 	"testing"
 
+	"github.com/lmorg/murex/config/profile/source"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/ref"
 	"github.com/lmorg/murex/test"
@@ -11,13 +12,13 @@ import (
 )
 
 //go:embed test/source*
-var source embed.FS
+var testSource embed.FS
 
 func TestDiskSource(t *testing.T) {
 	count.Tests(t, 1)
 
 	file := "test/source.mx"
-	test.ExistsFs(t, file, source)
+	test.ExistsFs(t, file, testSource)
 
 	disk, err := diskSource(file)
 	if err != nil {
@@ -33,7 +34,7 @@ func TestDiskSourceGz(t *testing.T) {
 	count.Tests(t, 1)
 
 	file := "test/source.mx.gz"
-	test.ExistsFs(t, file, source)
+	test.ExistsFs(t, file, testSource)
 
 	disk, err := diskSource(file)
 	if err != nil {
@@ -50,7 +51,7 @@ func TestExecSource(t *testing.T) {
 
 	lang.InitEnv()
 
-	source := `out: "testing"`
-	srcRef := ref.History.AddSource("(builtin)", "source/builtin", []byte(source))
-	execSource([]rune(source), srcRef, false)
+	block := `out: "testing"`
+	srcRef := ref.History.AddSource("(builtin)", "source/builtin", []byte(block))
+	source.Exec([]rune(block), srcRef, false)
 }
