@@ -18,17 +18,19 @@ func sumTest(t *testing.T, test *plan) {
 		panic(err)
 	}
 
-	var expV interface{}
-	if err := json.Unmarshal([]byte(test.expected), &expV); err != nil {
-		panic(err)
+	var expV any
+	if !test.error {
+		if err := json.Unmarshal([]byte(test.expected), &expV); err != nil {
+			panic(err)
+		}
+		b, err := json.Marshal(expV)
+		if err != nil {
+			panic(err)
+		}
+		test.expected = string(b)
 	}
-	b, err := json.Marshal(expV)
-	if err != nil {
-		panic(err)
-	}
-	test.expected = string(b)
 
-	var old interface{}
+	var old any
 	err = json.Unmarshal([]byte(test.original), &old)
 	if err != nil {
 		t.Error("Error unmarshalling original for alter.Sum()")
@@ -43,7 +45,7 @@ func sumTest(t *testing.T, test *plan) {
 
 	new := alter.StrToInterface(test.change)
 	v, err := alter.Sum(context.TODO(), old, pathS, new)
-	if err != nil {
+	if (err != nil) != test.error {
 		t.Error("Error received from alter.Sum()")
 		t.Logf("  original: %s", test.original)
 		t.Logf("  path:     %s: %v", test.path, pathS)
@@ -66,6 +68,9 @@ func sumTest(t *testing.T, test *plan) {
 		return
 	}
 
+	if test.error {
+		return
+	}
 	if string(actual) != test.expected {
 		t.Error("Expected does not match actual")
 		t.Logf("  original: %s.(%T)", test.original, old)
@@ -154,3 +159,15 @@ func TestSumMapInterface(t *testing.T) {
 
 	sumTest(t, &test)
 }
+
+// https://github.com/lmorg/murex/issues/850
+func TestSumIssue850(t *testing.T) {
+	test := plan{
+		original: `{}`,
+		path:     "/",
+		change:   `{ "key": [{"hello": "world"}] }`,
+		error:    true,
+	}
+
+	sumTest(t, &test)
+}
