@@ -15,7 +15,7 @@ const NoData = "no data returned"
 // output is human readable when output for a human but a single line machine
 // readable formatting for better support with iteration / concatenation when
 // output to system functions.
-func Marshal(v interface{}, isTTY bool) (b []byte, err error) {
+func Marshal(v any, isTTY bool) (b []byte, err error) {
 	b, err = marshal(v, isTTY)
 	if err != nil && strings.Contains(err.Error(), "unsupported type: map[interface {}]interface {}") {
 		b, err = marshal(deinterface(v), isTTY)
@@ -34,7 +34,7 @@ func Marshal(v interface{}, isTTY bool) (b []byte, err error) {
 }
 
 // marshal is a JSON marshaller which auto indents if output is a TTY
-func marshal(v interface{}, isTTY bool) (b []byte, err error) {
+func marshal(v any, isTTY bool) (b []byte, err error) {
 	//b, err = gojay.Marshal(v)
 	//if err == nil {
 	//	return
@@ -50,19 +50,19 @@ func marshal(v interface{}, isTTY bool) (b []byte, err error) {
 }
 
 // deinterface is used to fudge around the lack of support for
-// `map[interface{}]interface{}` in Go's JSON marshaller.
-func deinterface(v interface{}) interface{} {
+// `map[any]any` in Go's JSON marshaller.
+func deinterface(v any) any {
 	switch t := v.(type) {
-	case map[interface{}]interface{}:
-		newV := make(map[string]interface{})
+	case map[any]any:
+		newV := make(map[string]any)
 		for key := range t {
 			newV[fmt.Sprint(key)] = deinterface(t[key])
 		}
 		//debug.Log(fmt.Sprintf("Deinterface: %T\n", t))
 		return newV
 
-	case []interface{}:
-		newV := make([]interface{}, 0)
+	case []any:
+		newV := make([]any, 0)
 		for i := range t {
 			newV = append(newV, deinterface(t[i]))
 		}
