@@ -16,6 +16,11 @@ var rxPathPrefix *regexp.Regexp = regexp.MustCompile(`^[a-zA-Z]:[\\/]`)
 // NormalisePath takes a string and returns an absolute path if the string is a
 // relative path
 func NormalisePath(path string) string {
+	// bugfix: https://github.com/lmorg/murex/issues/789
+	if len(path) == 0 {
+		path = "."
+	}
+
 	pwd, err := os.Getwd()
 	if err == nil && path[0] != consts.PathSlash[0] && !rxPathPrefix.MatchString(path) {
 		path = pwd + consts.PathSlash + path
